@@ -1,4 +1,4 @@
-/* $Id: loadavg.h,v 1.27 2006/04/18 20:17:25 gpoo Exp $ */
+/* $Id: loadavg.h,v 1.24 2003/10/20 20:11:58 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -42,12 +42,12 @@ struct _glibtop_loadavg
 {
 	guint64 flags;
 	double loadavg [3];		/* GLIBTOP_LOADAVG_LOADAVG	*/
-	guint64 nr_running;		/* GLIBTOP_LOADAVG_NR_RUNNING	*/
-	guint64 nr_tasks;		/* GLIBTOP_LOADAVG_NR_TASKS	*/
-	guint64 last_pid;		/* GLIBTOP_LOADAVG_LAST_PID	*/
+	guint64 nr_running,		/* GLIBTOP_LOADAVG_NR_RUNNING	*/
+		nr_tasks,		/* GLIBTOP_LOADAVG_NR_TASKS	*/
+		last_pid;		/* GLIBTOP_LOADAVG_LAST_PID	*/
 };
 
-void glibtop_get_loadavg(glibtop_loadavg *buf);
+#define glibtop_get_loadavg(loadavg)	glibtop_get_loadavg_l(glibtop_global_server, loadavg)
 
 #if GLIBTOP_SUID_LOADAVG
 #define glibtop_get_loadavg_r		glibtop_get_loadavg_p
@@ -65,6 +65,16 @@ void glibtop_init_loadavg_s (glibtop *server);
 void glibtop_get_loadavg_s (glibtop *server, glibtop_loadavg *buf);
 #endif
 
+#ifdef GLIBTOP_NAMES
+
+/* You need to link with -lgtop_names to get this stuff here. */
+
+extern const char *glibtop_names_loadavg [];
+extern const unsigned glibtop_types_loadavg [];
+extern const char *glibtop_labels_loadavg [];
+extern const char *glibtop_descriptions_loadavg [];
+
+#endif
 
 G_END_DECLS
 
