@@ -1,4 +1,4 @@
-/* $Id: procargs.h,v 1.18 2004/07/07 20:22:58 bdejean Exp $ */
+/* $Id: procargs.h,v 1.19 2004/11/13 11:42:48 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -85,28 +85,6 @@ glibtop_get_proc_argv_l (glibtop *server, glibtop_proc_args *buf,
 #define glibtop_get_proc_argv(proc_args,pid,max_len) glibtop_get_proc_argv_l(glibtop_global_server, proc_args, pid, max_len)
 
 
-#if GLIBTOP_SUID_PROC_ARGS
-
-# define glibtop_get_proc_argv_r		glibtop_get_proc_args_p
-# define glibtop_init_proc_argv_p		glibtop_init_proc_args_p
-
-  char **
-  glibtop_get_proc_argv_p (glibtop *server, glibtop_proc_args *buf,
-			   pid_t pid, unsigned max_len);
-
-
-#else /* !GLIBTOP_SUID_PROC_ARGS */
-
-# define glibtop_get_proc_argv_r		glibtop_get_proc_args_s
-# define glibtop_init_proc_argv_s		glibtop_init_proc_args_s
-
-  char **
-  glibtop_get_proc_argv_s (glibtop *server, glibtop_proc_args *buf,
-			   pid_t pid, unsigned max_len);
-#endif /* GLIBTOP_SUID_PROC_ARGS */
-
-
-
 #ifdef GLIBTOP_NAMES
 
 /* You need to link with -lgtop_names to get this stuff here. */
